# -*- coding: utf-8 -*-

from django.test import TestCase
from logement.models import Logement
from datetime import datetime


class TestLogement(TestCase):
    "Test de l'objet Logement"

    def setUp(self):
        self.logement = Logement.objects.create(
            typel="ch",
            loyer=420,
            montant_charges=42,
            free_date=datetime.today(),
            adresse="42 rue riquet 31071 Toulouse",
            description="mon logement",
            pub_date=datetime.today(),
            nb_obsolete=0,
        )

    def test_adresse_sans_ville(self):
        self.assertEqual(self.logement.adresse_sans_ville(), "42 rue riquet  ")

    def test_loyer_complet(self):
        # 420 + 42 = 462
        self.assertEqual(self.logement.loyer_complet(), 462)

    def test_maj_coords(self):
        # 42 rue riquet, Toulouse
        self.logement.maj_coords()
        self.assertAlmostEqual(self.logement.longitude, 1.454, places=3)
        self.assertAlmostEqual(self.logement.latitude, 43.605, places=3)

    def test_est_obsolete(self):
        self.assertFalse(self.logement.est_obsolete())
